@@ -1,6 +1,7 @@
 import logging
 from queue import Empty, Queue
 from threading import Event, Thread, active_count
+from time import sleep
 from typing import Dict, Tuple, Type, Union
 
 from deltalanguage.wiring import (DeltaGraph,
@@ -57,7 +58,16 @@ class DeltaRuntimeExit(Exception):
 
 
 class DeltaPySimulator:
-    """Python Simulator of Deltaruntime.
+    """Python Simulator for running :py:class:`DeltaGraph`.
+
+    The main purpose of this simulator is debugging of the graph and basic
+    testing. Please note that this implementation is not
+    optimized for high performance, thus do not try to run big graphs in it,
+    instead use Deltasimulator package.
+
+    The advantage of this implementation is that you can debug nodes in
+    Python ecosystem without need to verilate Migen code and compile any
+    SystemC libraries.
 
     At initialization it spins out an individual ``threading.Thread``
     for each node's body. Inputs and outputs to which are managed by
@@ -76,7 +86,9 @@ class DeltaPySimulator:
         The level at which logs from messages between nodes are displayed.
         These are the same levels as in Python's :py:mod:`logging` package.
         By default only error logs are displayed.
-
+    tick_time : float
+        Time in seconds that the simulator waits before checking for
+        exceptions.
 
     .. note::
         In order to reduce computation the results of constant nodes are
@@ -123,9 +135,11 @@ class DeltaPySimulator:
     def __init__(self,
                  graph: DeltaGraph,
                  lvl: int = logging.ERROR,
-                 msg_lvl: int = logging.ERROR):
+                 msg_lvl: int = logging.ERROR,
+                 tick_time=0.001):
         self.log = make_logger(lvl, "DeltaPySimulator")
         self.msg_log = MessageLog(msg_lvl)
+        self.tick_time = tick_time
 
         # the graph
         self.graph = graph
@@ -348,6 +362,10 @@ class DeltaPySimulator:
             if isinstance(node, self.splitter_node_cls):
                 node.split()
 
+        # Release Python's GIL
+        if self.tick_time is not None:
+            sleep(self.tick_time)
+
     def _check_exceptions(self):
         """Check if any of the nodes has thrown an exception.
 
