@@ -21,6 +21,11 @@ from deltalanguage.wiring import (DeltaBlock,
                                   PySplitterBody,
                                   template_node_factory)
 
+from deltalanguage.lib.hal import HardwareAbstractionLayerNode
+from deltalanguage.lib.quantum_simulators import (ProjectqQuantumSimulator,
+                                                  QiskitQuantumSimulator)
+
+
 
 class PortSerialisationTest(unittest.TestCase):
 
@@ -209,6 +214,46 @@ class PythonNodeSerialisationTest(unittest.TestCase):
         interactive_body = prog.bodies[0].interactive.dillImpl
         self.assertEqual(interactive_body, a.get_serialised_body())
 
+    def test_projectQ_serialisation(self):
+        """Test ProjectQ nodes serialization/deserialization.
+
+        ProjectQ can't be fully serialized, we need to exclude from dill the
+        engine (c++ libraries). This test is to guarantee that when we deserialize
+        everything works as expected.
+        """
+
+        with DeltaGraph() as test_graph:
+            projectQ = HardwareAbstractionLayerNode(
+                ProjectqQuantumSimulator(register_size=2)).accept_command(command=0x4000000)
+
+        data, prog = serialize_graph(test_graph)
+        g_capnp = deserialize_graph(data)
+
+        # Checking that we are investigating the right node.
+        self.assertEqual(g_capnp.nodes[1].name.split("_")[0], "accept")
+        body = g_capnp.bodies[1].python.dillImpl
+
+        node = dill.loads(body)
+        node.eval(command=0x4000000)
+
+    def test_qiskit_serialisation(self):
+        """Test Qiskit nodes serialization/deserialization.
+
+        """
+
+        with DeltaGraph() as test_graph:
+            qiskit = HardwareAbstractionLayerNode(
+                QiskitQuantumSimulator(register_size=2)).accept_command(command=0x4000000)
+
+        data, prog = serialize_graph(test_graph)
+        g_capnp = deserialize_graph(data)
+
+        # Checking that we are investigating the right node.
+        self.assertEqual(g_capnp.nodes[1].name.split("_")[0], "accept")
+        body = g_capnp.bodies[1].python.dillImpl
+        node = dill.loads(body)
+        node.eval(command=0x4000000)
+
     def test_template_node_capnp(self):
         """Test TemplateNode.
 
